@@ -28,8 +28,6 @@
 #  include <config.h>
 #endif
 
-#ifdef BUILD_SEARCH
-
 #include <string.h>
 
 #include <glib.h>
@@ -38,8 +36,6 @@
 
 #include <gtk/gtk.h>
 
-#include <beagle/beagle.h>
-
 #include "brasero-search-entry.h"
 #include "brasero-layout.h"
 #include "brasero-setting.h"
@@ -47,7 +43,6 @@
 static void brasero_search_entry_class_init (BraseroSearchEntryClass *klass);
 static void brasero_search_entry_init (BraseroSearchEntry *sp);
 static void brasero_search_entry_finalize (GObject *object);
-static void brasero_search_entry_destroy (GtkObject *gtk_object);
 
 struct BraseroSearchEntryPrivate {
 	GtkWidget *button;
@@ -124,11 +119,9 @@ static void
 brasero_search_entry_class_init (BraseroSearchEntryClass *klass)
 {
 	GObjectClass *object_class = G_OBJECT_CLASS (klass);
-	GtkObjectClass *gtk_object_class = GTK_OBJECT_CLASS (klass);
 
 	parent_class = g_type_class_peek_parent (klass);
 	object_class->finalize = brasero_search_entry_finalize;
-	gtk_object_class->destroy = brasero_search_entry_destroy;
 
 	brasero_search_entry_signals[ACTIVATED_SIGNAL] =
 	    g_signal_new ("activated", G_OBJECT_CLASS_TYPE (object_class),
@@ -234,7 +227,7 @@ brasero_search_entry_init (BraseroSearchEntry *obj)
 					NULL);
 
 	/* set auto completion */
-	entry = GTK_BIN (obj->priv->combo)->child;
+	entry = gtk_bin_get_child (GTK_BIN (obj->priv->combo));
 	completion = gtk_entry_completion_new ();
 	gtk_entry_completion_set_model (completion, GTK_TREE_MODEL (store));
 	gtk_entry_completion_set_text_column (completion, BRASERO_SEARCH_ENTRY_DISPLAY_COL);
@@ -322,8 +315,9 @@ brasero_search_entry_init (BraseroSearchEntry *obj)
 			  obj);
 
 	/* add tooltips */
-	gtk_widget_set_tooltip_text (GTK_BIN (obj->priv->combo)->child,
-				     _("Type your keywords or choose 'All files' from the menu"));
+	gtk_widget_set_tooltip_text (gtk_bin_get_child (GTK_BIN (obj->priv->combo)),
+	                             _("Type your keywords or choose 'All files' from the menu"));
+
 	/* Translators: this is an image, a picture, not a "Disc Image" */
 	gtk_widget_set_tooltip_text (obj->priv->pictures,
 				     _("Select if you want to search among image files only"));
@@ -344,12 +338,6 @@ brasero_search_entry_init (BraseroSearchEntry *obj)
 	g_strfreev (value);
 }
 
-static void
-brasero_search_entry_destroy (GtkObject *gtk_object)
-{
-	GTK_OBJECT_CLASS (parent_class)->destroy (gtk_object);
-}
-
 static void
 brasero_search_entry_finalize (GObject *object)
 {
@@ -361,7 +349,10 @@ brasero_search_entry_finalize (GObject *object)
 		g_source_remove (cobj->priv->search_id);
 		cobj->priv->search_id = 0;
 	}
-
+	if (cobj->priv->keywords) {
+		g_free (cobj->priv->keywords);
+		cobj->priv->keywords = NULL;
+	}
 	g_free (cobj->priv);
 	cobj->priv = NULL;
 
@@ -417,7 +408,7 @@ brasero_search_entry_check_keywords (BraseroSearchEntry *entry)
 	 * sets a pointer to the string; that's why we can't free the
 	 * keywords until the query has been sent and even then ... */
 
-	keywords = gtk_entry_get_text (GTK_ENTRY (GTK_BIN (entry->priv->combo)->child));
+	keywords = gtk_entry_get_text (GTK_ENTRY (gtk_bin_get_child (GTK_BIN (entry->priv->combo))));
 	if (!keywords)
 		return;
 
@@ -565,7 +556,7 @@ brasero_search_entry_add_current_keyword_to_history (BraseroSearchEntry *entry)
 	GtkTreeIter iter;
 
 	/* we don't want to add static entry */
-	keywords =  gtk_entry_get_text (GTK_ENTRY (GTK_BIN (entry->priv->combo)->child));
+	keywords =  gtk_entry_get_text (GTK_ENTRY (gtk_bin_get_child (GTK_BIN (entry->priv->combo))));
 	if (!keywords || !strcmp (keywords, _("All files")))
 		return;
 
@@ -621,88 +612,32 @@ end:
 	brasero_search_entry_save_history (entry);
 }
 
-BeagleQuery *
-brasero_search_entry_get_query (BraseroSearchEntry *entry)
+gboolean
+brasero_search_entry_set_query (BraseroSearchEntry *entry,
+                                BraseroSearchEngine *search)
 {
-	BeagleQuery *query;
-	BeagleQueryPartHuman *text;
-	BeagleQueryPartOr *or_part = NULL;
+	BraseroSearchScope scope = BRASERO_SEARCH_SCOPE_ANY;
+	const gchar *keywords = NULL;
 
-	/* Not sure about all this */
-	query = beagle_query_new ();
+	if (strcmp (entry->priv->keywords, _("All files")))
+		keywords = entry->priv->keywords;
 
-	if (strcmp (entry->priv->keywords, _("All files"))) {
-		BeagleQueryPartHuman *text;
+	if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (entry->priv->documents)))
+		scope |= BRASERO_SEARCH_SCOPE_DOCUMENTS;
 
-		text = beagle_query_part_human_new ();
-		beagle_query_part_human_set_string (text, entry->priv->keywords);
-		beagle_query_part_set_logic (BEAGLE_QUERY_PART (text),
-					     BEAGLE_QUERY_PART_LOGIC_REQUIRED);
+	if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (entry->priv->pictures)))
+		scope |= BRASERO_SEARCH_SCOPE_PICTURES;
 
-		beagle_query_add_part (query, BEAGLE_QUERY_PART (text));
-	}
+	if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (entry->priv->music)))
+		scope |= BRASERO_SEARCH_SCOPE_MUSIC;
 
-	text = beagle_query_part_human_new ();
-	beagle_query_part_human_set_string (text, "type:File");
-	beagle_query_add_part (query, BEAGLE_QUERY_PART (text));
+	if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (entry->priv->video)))
+		scope |= BRASERO_SEARCH_SCOPE_VIDEO;
 
-	if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (entry->priv->documents))) {
-		BeagleQueryPartProperty *filetype;
+	brasero_search_engine_new_query (search, keywords);
+	brasero_search_engine_set_query_scope (search, scope);
 
-		if (!or_part)
-			or_part = beagle_query_part_or_new ();
-
-		filetype = beagle_query_part_property_new ();
-		beagle_query_part_property_set_property_type (filetype, BEAGLE_PROPERTY_TYPE_KEYWORD);
-		beagle_query_part_property_set_key (filetype, "beagle:FileType");
-		beagle_query_part_property_set_value (filetype, "document");
-		beagle_query_part_or_add_subpart (or_part, BEAGLE_QUERY_PART (filetype));
-	}
-
-	if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (entry->priv->pictures))) {
-		BeagleQueryPartProperty *filetype;
-
-		if (!or_part)
-			or_part = beagle_query_part_or_new ();
-
-		filetype = beagle_query_part_property_new ();
-		beagle_query_part_property_set_property_type (filetype, BEAGLE_PROPERTY_TYPE_KEYWORD);
-		beagle_query_part_property_set_key (filetype, "beagle:FileType");
-		beagle_query_part_property_set_value (filetype, "image");
-		beagle_query_part_or_add_subpart (or_part, BEAGLE_QUERY_PART (filetype));
-	}
-
-	if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (entry->priv->music))) {
-		BeagleQueryPartProperty *filetype;
-
-		if (!or_part)
-			or_part = beagle_query_part_or_new ();
-
-		filetype = beagle_query_part_property_new ();
-		beagle_query_part_property_set_property_type (filetype, BEAGLE_PROPERTY_TYPE_KEYWORD);
-		beagle_query_part_property_set_key (filetype, "beagle:FileType");
-		beagle_query_part_property_set_value (filetype, "audio");
-		beagle_query_part_or_add_subpart (or_part, BEAGLE_QUERY_PART (filetype));
-	}
-
-	if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (entry->priv->video))) {
-		BeagleQueryPartProperty *filetype;
-
-		if (!or_part)
-			or_part = beagle_query_part_or_new ();
-
-		filetype = beagle_query_part_property_new ();
-		beagle_query_part_property_set_property_type (filetype, BEAGLE_PROPERTY_TYPE_KEYWORD);
-		beagle_query_part_property_set_key (filetype, "beagle:FileType");
-		beagle_query_part_property_set_value (filetype, "video");
-		beagle_query_part_or_add_subpart (or_part, BEAGLE_QUERY_PART (filetype));
-	}
-
-	if (!or_part)
-		return query;
-
-	beagle_query_add_part (query, BEAGLE_QUERY_PART (or_part));
-	return query;
+	return TRUE;
 }
 
 void
@@ -727,4 +662,3 @@ brasero_search_entry_set_context (BraseroSearchEntry *self,
 	}
 }
 
-#endif /*BUILD_SEARCH*/
