@@ -361,7 +361,8 @@ brasero_video_disc_directory_dialog (BraseroVideoDisc *self)
 				     GTK_MESSAGE_WARNING);
 
 	gtk_message_dialog_format_secondary_text (GTK_MESSAGE_DIALOG (dialog),
-						  _("Directories cannot be added to video discs."));
+	                                          "%s.",
+						  _("Directories cannot be added to video or audio discs"));
 
 	gtk_dialog_add_buttons (GTK_DIALOG (dialog),
 				GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
@@ -956,6 +957,11 @@ brasero_video_disc_button_pressed_cb (GtkTreeView *tree,
 
 	priv = BRASERO_VIDEO_DISC_PRIVATE (self);
 
+	/* Avoid minding signals that happen out of the tree area (like in the 
+	 * headers for example) */
+	if (event->window != gtk_tree_view_get_bin_window (GTK_TREE_VIEW (tree)))
+		return FALSE;
+
 	widget_class = GTK_WIDGET_GET_CLASS (tree);
 
 	if (event->button == 3) {
@@ -1137,10 +1143,10 @@ brasero_video_disc_key_released_cb (GtkTreeView *tree,
 	if (priv->editing)
 		return FALSE;
 
-	if (event->keyval == GDK_KP_Delete || event->keyval == GDK_Delete) {
+	if (event->keyval == GDK_KEY_KP_Delete || event->keyval == GDK_KEY_Delete) {
 		brasero_video_disc_delete_selected (BRASERO_DISC (self));
 	}
-	else if (event->keyval == GDK_F2)
+	else if (event->keyval == GDK_KEY_F2)
 		brasero_video_disc_rename_activated (self);
 
 	return FALSE;
